@@ -46,22 +46,10 @@ extern "C" {
 /* User event type emitted when a stream fragment is ready to be
  * refilled with more audio data.
  * Must be in 512 <= n < 1024
- *
  */
 #define ALLEGRO_EVENT_AUDIO_STREAM_FRAGMENT  (513)
 #define ALLEGRO_EVENT_AUDIO_STREAM_FINISHED  (514)
 
-#define ALLEGRO_EVENT_AUDIO_RECORDER_FRAGMENT       (515)
-
-typedef struct ALLEGRO_AUDIO_RECORDER_EVENT ALLEGRO_AUDIO_RECORDER_EVENT;
-struct ALLEGRO_AUDIO_RECORDER_EVENT
-{
-   _AL_EVENT_HEADER(struct ALLEGRO_AUDIO_RECORDER)
-   struct ALLEGRO_USER_EVENT_DESCRIPTOR *__internal__descr;
-   void *buffer;
-   unsigned int samples;
-};
-
 
 /* Enum: ALLEGRO_AUDIO_DEPTH
  */
@@ -136,6 +124,7 @@ enum ALLEGRO_MIXER_QUALITY
  */
 #define ALLEGRO_AUDIO_PAN_NONE      (-1000.0f)
 
+
 /* Type: ALLEGRO_SAMPLE
  */
 typedef struct ALLEGRO_SAMPLE ALLEGRO_SAMPLE;
@@ -171,11 +160,6 @@ typedef struct ALLEGRO_MIXER ALLEGRO_MIXER;
 typedef struct ALLEGRO_VOICE ALLEGRO_VOICE;
 
 
-/* Type: ALLEGRO_AUDIO_RECORDER
- */
-typedef struct ALLEGRO_AUDIO_RECORDER ALLEGRO_AUDIO_RECORDER;
-
-
 #ifndef __cplusplus
 typedef enum ALLEGRO_AUDIO_DEPTH ALLEGRO_AUDIO_DEPTH;
 typedef enum ALLEGRO_CHANNEL_CONF ALLEGRO_CHANNEL_CONF;
@@ -260,7 +244,6 @@ ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_PLAYMODE, al_get_audio_stream_playmode, (const AL
 
 ALLEGRO_KCM_AUDIO_FUNC(bool, al_get_audio_stream_playing, (const ALLEGRO_AUDIO_STREAM *spl));
 ALLEGRO_KCM_AUDIO_FUNC(bool, al_get_audio_stream_attached, (const ALLEGRO_AUDIO_STREAM *spl));
-ALLEGRO_KCM_AUDIO_FUNC(uint64_t, al_get_audio_stream_played_samples, (const ALLEGRO_AUDIO_STREAM *stream));
 
 ALLEGRO_KCM_AUDIO_FUNC(void *, al_get_audio_stream_fragment, (const ALLEGRO_AUDIO_STREAM *stream));
 
@@ -340,9 +323,6 @@ ALLEGRO_KCM_AUDIO_FUNC(uint32_t, al_get_allegro_audio_version, (void));
 ALLEGRO_KCM_AUDIO_FUNC(size_t, al_get_channel_count, (ALLEGRO_CHANNEL_CONF conf));
 ALLEGRO_KCM_AUDIO_FUNC(size_t, al_get_audio_depth_size, (ALLEGRO_AUDIO_DEPTH conf));
 
-ALLEGRO_KCM_AUDIO_FUNC(void, al_fill_silence, (void *buf, unsigned int samples,
-      ALLEGRO_AUDIO_DEPTH depth, ALLEGRO_CHANNEL_CONF chan_conf));
-
 /* Simple audio layer */
 ALLEGRO_KCM_AUDIO_FUNC(bool, al_reserve_samples, (int reserve_samples));
 ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_MIXER *, al_get_default_mixer, (void));
@@ -382,21 +362,12 @@ ALLEGRO_KCM_AUDIO_FUNC(bool, al_save_sample_f, (ALLEGRO_FILE* fp, const char *id
 ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_AUDIO_STREAM *, al_load_audio_stream_f, (ALLEGRO_FILE* fp, const char *ident,
 	size_t buffer_count, unsigned int samples));
 
-/* Recording functions */
-ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_AUDIO_RECORDER *, al_create_audio_recorder, (size_t fragment_count,
-   unsigned int samples, unsigned int freq, ALLEGRO_AUDIO_DEPTH depth, ALLEGRO_CHANNEL_CONF chan_conf));
-ALLEGRO_KCM_AUDIO_FUNC(bool, al_start_audio_recorder, (ALLEGRO_AUDIO_RECORDER *r));
-ALLEGRO_KCM_AUDIO_FUNC(void, al_stop_audio_recorder, (ALLEGRO_AUDIO_RECORDER *r));
-ALLEGRO_KCM_AUDIO_FUNC(bool, al_is_audio_recorder_recording, (ALLEGRO_AUDIO_RECORDER *r));
-ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_EVENT_SOURCE *, al_get_audio_recorder_event_source,
-   (ALLEGRO_AUDIO_RECORDER *r));
-ALLEGRO_KCM_AUDIO_FUNC(ALLEGRO_AUDIO_RECORDER_EVENT *, al_get_audio_recorder_event, (ALLEGRO_EVENT *event));
-ALLEGRO_KCM_AUDIO_FUNC(void, al_destroy_audio_recorder, (ALLEGRO_AUDIO_RECORDER *r));
-   
+
 #ifdef __cplusplus
 } /* End extern "C" */
 #endif
 
+
 #endif
 
 
