@@ -4,10 +4,7 @@
 
 #include "iio.h"
 
-/* Do NOT simplify this to just (x), it doesn't work in MSVC. */
-#define INT_TO_BOOL(x)   ((x) != 0)
-
-ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f, int flags)
+ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f)
 {
    ALLEGRO_BITMAP *b;
    int c;
@@ -18,7 +15,6 @@ ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f, int flags)
    ALLEGRO_LOCKED_REGION *lr;
    unsigned char *buf;
    PalEntry pal[256];
-   bool keep_index;
    ASSERT(f);
 
    al_fgetc(f);                    /* skip manufacturer ID */
@@ -61,8 +57,6 @@ ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f, int flags)
    if (!b) {
       return NULL;
    }
-   
-   keep_index = INT_TO_BOOL(flags & ALLEGRO_KEEP_INDEX);
 
    al_set_errno(0);
 
@@ -77,12 +71,7 @@ ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f, int flags)
       buf = (unsigned char *)al_malloc(bytes_per_line * 3);
    }
 
-   if (bpp == 8 && keep_index) {
-      lr = al_lock_bitmap(b, ALLEGRO_PIXEL_FORMAT_SINGLE_CHANNEL_8, ALLEGRO_LOCK_WRITEONLY);
-   }
-   else {
-      lr = al_lock_bitmap(b, ALLEGRO_PIXEL_FORMAT_ABGR_8888_LE, ALLEGRO_LOCK_WRITEONLY);
-   }
+   lr = al_lock_bitmap(b, ALLEGRO_PIXEL_FORMAT_ABGR_8888_LE, ALLEGRO_LOCK_WRITEONLY);
    if (!lr) {
       al_free(buf);
       return NULL;
@@ -145,15 +134,10 @@ ALLEGRO_BITMAP *_al_load_pcx_f(ALLEGRO_FILE *f, int flags)
          char *dest = (char*)lr->data + y*lr->pitch;
          for (x = 0; x < width; x++) {
             int index = buf[y * width + x];
-            if (keep_index) {
-               dest[x] = index;
-            }
-            else {
-               dest[x*4    ] = pal[index].r;
-               dest[x*4 + 1] = pal[index].g;
-               dest[x*4 + 2] = pal[index].b;
-               dest[x*4 + 3] = 255;
-            }
+            dest[x*4    ] = pal[index].r;
+            dest[x*4 + 1] = pal[index].g;
+            dest[x*4 + 2] = pal[index].b;
+            dest[x*4 + 3] = 255;
          }
       }
    }
@@ -254,7 +238,7 @@ bool _al_save_pcx_f(ALLEGRO_FILE *f, ALLEGRO_BITMAP *bmp)
       return true;
 }
 
-ALLEGRO_BITMAP *_al_load_pcx(const char *filename, int flags)
+ALLEGRO_BITMAP *_al_load_pcx(const char *filename)
 {
    ALLEGRO_FILE *f;
    ALLEGRO_BITMAP *bmp;
@@ -264,7 +248,7 @@ ALLEGRO_BITMAP *_al_load_pcx(const char *filename, int flags)
    if (!f)
       return NULL;
 
-   bmp = _al_load_pcx_f(f, flags);
+   bmp = _al_load_pcx_f(f);
 
    al_fclose(f);
 
@@ -274,19 +258,18 @@ ALLEGRO_BITMAP *_al_load_pcx(const char *filename, int flags)
 bool _al_save_pcx(const char *filename, ALLEGRO_BITMAP *bmp)
 {
    ALLEGRO_FILE *f;
-   bool retsave;
-   bool retclose;
+   bool ret;
    ASSERT(filename);
 
    f = al_fopen(filename, "wb");
    if (!f)
       return false;
 
-   retsave = _al_save_pcx_f(f, bmp);
+   ret = _al_save_pcx_f(f, bmp);
 
-   retclose = al_fclose(f);
+   al_fclose(f);
 
-   return retsave && retclose;
+   return ret;
 }
 
 
