@@ -37,6 +37,16 @@ static wchar_t* wlog_edit_control = L"EDIT";
 static bool wlog_unicode = false;
 
 
+bool _al_init_native_dialog_addon(void)
+{
+   return true;
+}
+
+void _al_shutdown_native_dialog_addon(void)
+{
+}
+
+
 static bool select_folder(ALLEGRO_DISPLAY_WIN *win_display,
    ALLEGRO_NATIVE_DIALOG *fd)
 {
