@@ -3,20 +3,25 @@
  *
  * Options are:
  *
+ *    --pandoc PANDOC
  *    --protos PROTOS-FILE
  *    --to FORMAT (html, man, latex, texinfo, etc.)
  *    --raise-sections
  *
  * Unknown options are passed through to Pandoc.
- *
- * Environment variables: PANDOC
  */
 
 #include <ctype.h>
+#include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
 #if defined(_BSD_SOURCE) || defined(_SVID_SOURCE) || (_XOPEN_SOURCE >= 500)
    #include <unistd.h>
+   #define USE_MKSTEMP 1
+#elif defined(_MSC_VER)
+   #define TEMPNAM(d, p)   (_tempnam((d), (p)))
+#else
+   #define TEMPNAM(d, p)   (tempnam((d), (p)))
 #endif
 
 #include "aatree.h"
@@ -29,8 +34,8 @@ dstr pandoc_options  = "";
 dstr protos_file     = "protos";
 dstr to_format       = "html";
 bool raise_sections  = false;
-char tmp_preprocess_output[80];
-char tmp_pandoc_output[80];
+dstr tmp_preprocess_output;
+dstr tmp_pandoc_output;
 
 static Aatree *protos = &aa_nil;
 
@@ -62,14 +67,8 @@ int main(int argc, char *argv[])
 
 static int process_options(int argc, char *argv[])
 {
-   char *p;
    int i;
 
-   p = getenv("PANDOC");
-   if (p) {
-      d_assign(pandoc, p);
-   }
-
    for (i = 1; i < argc; ) {
       if (streq(argv[i], "--")) {
          i++;
@@ -78,7 +77,11 @@ static int process_options(int argc, char *argv[])
       if (argv[i][0] != '-') {
          break;
       }
-      if (streq(argv[i], "--protos")) {
+      if (streq(argv[i], "--pandoc")) {
+         d_assign(pandoc, argv[i + 1]);
+         i += 2;
+      }
+      else if (streq(argv[i], "--protos")) {
          d_assign(protos_file, argv[i + 1]);
          i += 2;
       }
@@ -124,7 +127,7 @@ static void load_prototypes(const char *filename)
          newtext = d_submatch(2);
 
          d_assign(text, lookup_prototype(name));
-         strcat(text, "\n    ");
+         strcat(text, "\n");
          strcat(text, newtext);
          protos = aa_insert(protos, name, text);
       }
@@ -146,18 +149,21 @@ void generate_temp_file(char *filename)
    /* gcc won't shut up if we use tmpnam() so we'll use mkstemp() if it is
     * likely to be available.
     */
-#if defined(_BSD_SOURCE) || defined(_SVID_SOURCE) || (_XOPEN_SOURCE >= 500)
+#ifdef USE_MKSTEMP
    int fd;
-   strcpy(filename, ",make_doc_tmp.XXXXXX");
+   d_assign(filename, "make_doc_tmp.XXXXXX");
    fd = mkstemp(filename);
    if (fd == -1) {
       d_abort("could not generate temporary file name", "");
    }
    close(fd);
 #else
-   if (!tmpnam(filename)) {
+   char *name = TEMPNAM(NULL, "make_doc_tmp.");
+   if (!name) {
       d_abort("could not generate temporary file name", "");
    }
+   d_assign(filename, name);
+   free(name);
 #endif
 }
 
@@ -190,7 +196,7 @@ void call_pandoc(const char *input, const char *output,
       }
    }
 
-   sprintf(cmd, "%s %s %s %s --to %s --output %s",
+   sprintf(cmd, "\"%s\" %s %s %s --to %s --output %s",
       pandoc, input_native, pandoc_options, extra_options, to_format, output);
    if (system(cmd) != 0) {
       d_abort("system call failed: ", cmd);
