@@ -277,7 +277,6 @@ static void init(void)
    ex.myfont = al_load_font("data/font.tga", 0, 0);
    if (!ex.myfont) {
       abort_example("data/font.tga not found\n");
-      exit(1);
    }
    ex.example = create_example_bitmap();
 
@@ -293,7 +292,6 @@ int main(void)
 
    if (!al_init()) {
       abort_example("Could not init Allegro.\n");
-      return 1;
    }
 
    al_init_primitives_addon();
@@ -305,7 +303,6 @@ int main(void)
    display = al_create_display(640, 480);
    if (!display) {
       abort_example("Error creating display\n");
-      return 1;
    }
 
    init();
