@@ -34,10 +34,10 @@ private:
    Label operation_label[6];
    List operations[6];
    Label rgba_label[2];
-   VSlider r[2];
-   VSlider g[2];
-   VSlider b[2];
-   VSlider a[2];
+   HSlider r[2];
+   HSlider g[2];
+   HSlider b[2];
+   HSlider a[2];
 
 public:
    Prog(const Theme & theme, ALLEGRO_DISPLAY *display);
@@ -90,7 +90,11 @@ Prog::Prog(const Theme & theme, ALLEGRO_DISPLAY *display) :
       l.append_item("ZERO");
       l.append_item("ALPHA");
       l.append_item("INVERSE");
-      d.add(l, 1 + i * 3, 25, 3, 6);
+      l.append_item("SRC_COLOR");
+      l.append_item("DEST_COLOR");
+      l.append_item("INV_SRC_COLOR");
+      l.append_item("INV_DEST_COLOR");
+      d.add(l, 1 + i * 3, 25, 3, 9);
    }
 
    for (int i = 4; i < 6; i++) {
@@ -103,20 +107,20 @@ Prog::Prog(const Theme & theme, ALLEGRO_DISPLAY *display) :
       d.add(l, 1 + i * 3, 25, 3, 6);
    }
 
-   rgba_label[0] = Label("RGBA");
-   rgba_label[1] = Label("RGBA");
-   d.add(rgba_label[0], 1, 32, 4, 1);
-   d.add(rgba_label[1], 7, 32, 4, 1);
+   rgba_label[0] = Label("Source tint/color RGBA");
+   rgba_label[1] = Label("Dest tint/color RGBA");
+   d.add(rgba_label[0], 1, 34, 5, 1);
+   d.add(rgba_label[1], 7, 34, 5, 1);
 
    for (int i = 0; i < 2; i++) {
-      r[i] = VSlider(255, 255);
-      g[i] = VSlider(255, 255);
-      b[i] = VSlider(255, 255);
-      a[i] = VSlider(255, 255);
-      d.add(r[i], 1 + i * 6, 33, 1, 6);
-      d.add(g[i], 2 + i * 6, 33, 1, 6);
-      d.add(b[i], 3 + i * 6, 33, 1, 6);
-      d.add(a[i], 4 + i * 6, 33, 1, 6);
+      r[i] = HSlider(255, 255);
+      g[i] = HSlider(255, 255);
+      b[i] = HSlider(255, 255);
+      a[i] = HSlider(255, 255);
+      d.add(r[i], 1 + i * 6, 35, 5, 1);
+      d.add(g[i], 1 + i * 6, 36, 5, 1);
+      d.add(b[i], 1 + i * 6, 37, 5, 1);
+      d.add(a[i], 1 + i * 6, 38, 5, 1);
    }
 }
 
@@ -142,6 +146,14 @@ int str_to_blend_mode(const std::string & str)
       return ALLEGRO_ZERO;
    if (str == "ONE")
       return ALLEGRO_ONE;
+   if (str == "SRC_COLOR")
+      return ALLEGRO_SRC_COLOR;
+   if (str == "DEST_COLOR")
+      return ALLEGRO_DEST_COLOR;
+   if (str == "INV_SRC_COLOR")
+      return ALLEGRO_INVERSE_SRC_COLOR;
+   if (str == "INV_DEST_COLOR")
+      return ALLEGRO_INVERSE_DEST_COLOR;
    if (str == "ALPHA")
       return ALLEGRO_ALPHA;
    if (str == "INVERSE")
@@ -305,7 +317,6 @@ int main(int argc, char *argv[])
 
    if (!al_init()) {
       abort_example("Could not init Allegro\n");
-      return 1;
    }
    al_init_primitives_addon();
    al_install_keyboard();
@@ -318,23 +329,19 @@ int main(int argc, char *argv[])
    display = al_create_display(800, 600);
    if (!display) {
       abort_example("Unable to create display\n");
-      return 1;
    }
 
    font = al_load_font("data/fixed_font.tga", 0, 0);
    if (!font) {
       abort_example("Failed to load data/fixed_font.tga\n");
-      return 1;
    }
    allegro = al_load_bitmap("data/allegro.pcx");
    if (!allegro) {
       abort_example("Failed to load data/allegro.pcx\n");
-      return 1;
    }
-   mysha = al_load_bitmap("data/mysha.pcx");
+   mysha = al_load_bitmap("data/mysha256x256.png");
    if (!mysha) {
-      abort_example("Failed to load data/mysha.pcx\n");
-      return 1;
+      abort_example("Failed to load data/mysha256x256.png\n");
    }
    
    target = al_create_bitmap(320, 200);
