@@ -50,7 +50,7 @@ static void redraw(void)
       ALLEGRO_BITMAP *bmp = example.bitmaps[example.bitmap][i];
       float bw = al_get_bitmap_width(bmp);
       float bh = al_get_bitmap_height(bmp);
-      float t = 1 - 2 * fabs((example.ticks % (FPS * 16)) / 16.0 / FPS - 0.5);
+      float t = 1 - 2 * fabsf((example.ticks % (FPS * 16)) / 16.0 / FPS - 0.5);
       float scale;
       float angle = example.ticks * ALLEGRO_PI * 2 / FPS / 8;
       
@@ -83,12 +83,10 @@ int main(void)
 
    if (!al_init()) {
       abort_example("Failed to init Allegro.\n");
-      return 1;
    }
 
    if (!al_init_image_addon()) {
       abort_example("Failed to init IIO addon.\n");
-      return 1;
    }
 
    al_init_font_addon();
@@ -97,29 +95,24 @@ int main(void)
 
    if (!example.display) {
       abort_example("Error creating display.\n");
-      return 1;
    }
 
    if (!al_install_keyboard()) {
       abort_example("Error installing keyboard.\n");
-      return 1;
    }
     
    if (!al_install_mouse()) {
-        abort_example("Error installing mouse.\n");
-        return 1;
-    }
+      abort_example("Error installing mouse.\n");
+   }
 
    example.font = al_load_font("data/fixed_font.tga", 0, 0);
    if (!example.font) {
       abort_example("Error loading data/fixed_font.tga\n");
-      return 1;
    }
    
    mysha = al_load_bitmap("data/mysha256x256.png");
    if (!mysha) {
       abort_example("Error loading data/mysha256x256.png\n");
-      return 1;
    }
 
    for (i = 0; i < 6; i++) {
