@@ -27,11 +27,7 @@
  *  Public Windows-related API
  */
 
-AL_FUNC(HWND, al_get_win_window_handle,      (ALLEGRO_DISPLAY *));
-AL_FUNC(bool, al_win_add_window_callback,    (ALLEGRO_DISPLAY *,
-   bool (*)(ALLEGRO_DISPLAY *, UINT, WPARAM, LPARAM, void *), void *userdata));
-AL_FUNC(bool, al_win_remove_window_callback, (ALLEGRO_DISPLAY *,
-   bool (*)(ALLEGRO_DISPLAY *, UINT, WPARAM, LPARAM, void *), void *userdata));
+AL_FUNC(HWND,               al_get_win_window_handle,           (ALLEGRO_DISPLAY *));
 
 #ifdef __cplusplus
    }
