@@ -7,6 +7,7 @@
 #include "allegro5/bitmap.h"
 #include "allegro5/internal/aintern_events.h"
 
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -28,11 +29,10 @@ struct ALLEGRO_DISPLAY_INTERFACE
    bool (*acknowledge_resize)(ALLEGRO_DISPLAY *d);
    bool (*resize_display)(ALLEGRO_DISPLAY *d, int width, int height);
    void (*quick_size)(ALLEGRO_DISPLAY *d);
-   int (*get_orientation)(ALLEGRO_DISPLAY *d);
 
    ALLEGRO_BITMAP *(*create_bitmap)(ALLEGRO_DISPLAY *d,
-      int w, int h, int format, int flags);
-
+   	int w, int h);
+   
    void (*set_target_bitmap)(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap);
    ALLEGRO_BITMAP *(*get_backbuffer)(ALLEGRO_DISPLAY *d);
 
@@ -43,6 +43,9 @@ struct ALLEGRO_DISPLAY_INTERFACE
    void (*draw_memory_bitmap_region)(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap,
       float sx, float sy, float sw, float sh, int flags);
 
+   ALLEGRO_BITMAP *(*create_sub_bitmap)(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *parent,
+      int x, int y, int width, int height);
+
    bool (*wait_for_vsync)(ALLEGRO_DISPLAY *display);
 
    bool (*set_mouse_cursor)(ALLEGRO_DISPLAY *display,
@@ -56,8 +59,6 @@ struct ALLEGRO_DISPLAY_INTERFACE
 
    void (*set_window_position)(ALLEGRO_DISPLAY *display, int x, int y);
    void (*get_window_position)(ALLEGRO_DISPLAY *display, int *x, int *y);
-   bool (*set_window_constraints)(ALLEGRO_DISPLAY *display, int min_w, int min_h, int max_w, int max_h);
-   bool (*get_window_constraints)(ALLEGRO_DISPLAY *display,  int *min_w, int *min_h, int *max_w, int *max_h);
    bool (*set_display_flag)(ALLEGRO_DISPLAY *display, int flag, bool onoff);
    void (*set_window_title)(ALLEGRO_DISPLAY *display, const char *title);
    
@@ -65,17 +66,8 @@ struct ALLEGRO_DISPLAY_INTERFACE
    void* (*prepare_vertex_cache)(ALLEGRO_DISPLAY *d, int num_new_vertices);
    
    void (*update_transformation)(ALLEGRO_DISPLAY* d, ALLEGRO_BITMAP *target);
-   void (*set_projection)(ALLEGRO_DISPLAY *d);
 
    void (*shutdown)(void);
-
-   void (*acknowledge_drawing_halt)(ALLEGRO_DISPLAY *d);
-   void (*acknowledge_drawing_resume)(ALLEGRO_DISPLAY *d);
-      
-   void (*set_display_option)(ALLEGRO_DISPLAY *display, int option, int val);
-
-   void (*clear_depth_buffer)(ALLEGRO_DISPLAY *display, float x);
-   void (*update_render_state)(ALLEGRO_DISPLAY *display);
 };
 
 
@@ -91,20 +83,13 @@ typedef struct ALLEGRO_BLENDER
    int blend_alpha_dest;
 } ALLEGRO_BLENDER;
 
-typedef struct _ALLEGRO_RENDER_STATE {
-   int write_mask;
-   int depth_test, depth_function;
-   int alpha_test, alpha_function, alpha_test_value;
-} _ALLEGRO_RENDER_STATE;
-
-
 /* These are settings Allegro itself doesn't really care about on its
  * own, but which users may want to specify for a display anyway.
  */
-ALLEGRO_STATIC_ASSERT(aintern_display, ALLEGRO_DISPLAY_OPTIONS_COUNT <= 64);
+ALLEGRO_STATIC_ASSERT(aintern_display, ALLEGRO_DISPLAY_OPTIONS_COUNT <= 32);
 typedef struct
 {
-   int64_t required, suggested; /* Bitfields. */
+   int required, suggested; /* Bitfields. */
    int settings[ALLEGRO_DISPLAY_OPTIONS_COUNT];
 
    /* These are come in handy when creating a context. */
@@ -120,8 +105,6 @@ struct ALLEGRO_DISPLAY
    int refresh_rate;
    int flags;
    int w, h;
-   int min_w, min_h;
-   int max_w, max_h;
    
    int backbuffer_format; /* ALLEGRO_PIXELFORMAT */
 
@@ -129,24 +112,16 @@ struct ALLEGRO_DISPLAY
    struct ALLEGRO_OGL_EXTRAS *ogl_extras;
 
    _AL_VECTOR bitmaps; /* A list of bitmaps created for this display. */
-
+   
    int num_cache_vertices;
    bool cache_enabled;
    int vertex_cache_size;
    void* vertex_cache;
    uintptr_t cache_texture;
-
+   
    ALLEGRO_BLENDER cur_blender;
-
-   ALLEGRO_SHADER* default_shader;
-
-   ALLEGRO_TRANSFORM proj_transform;
-   ALLEGRO_TRANSFORM view_transform;
-
-   _ALLEGRO_RENDER_STATE render_state;
-
-   _AL_VECTOR display_invalidated_callbacks;
-   _AL_VECTOR display_validated_callbacks;
+   
+   void (*display_invalidated)(ALLEGRO_DISPLAY*);
 };
 
 int  _al_score_display_settings(ALLEGRO_EXTRA_DISPLAY_SETTINGS *eds, ALLEGRO_EXTRA_DISPLAY_SETTINGS *ref);
@@ -157,22 +132,15 @@ int  _al_display_settings_sorter(const void *p0, const void *p1);
 
 void _al_destroy_display_bitmaps(ALLEGRO_DISPLAY *d);
 
-/* This is called from the primitives addon and for shaders. */
-AL_FUNC(void, _al_add_display_invalidated_callback, (ALLEGRO_DISPLAY *display,
+/* This is called from the primitives addon. */
+AL_FUNC(void, _al_set_display_invalidated_callback, (ALLEGRO_DISPLAY *display,
    void (*display_invalidated)(ALLEGRO_DISPLAY*)));
-AL_FUNC(void, _al_add_display_validated_callback, (ALLEGRO_DISPLAY *display,
-   void (*display_validated)(ALLEGRO_DISPLAY*)));
-AL_FUNC(void, _al_remove_display_invalidated_callback, (ALLEGRO_DISPLAY *display,
-   void (*display_invalidated)(ALLEGRO_DISPLAY*)));
-AL_FUNC(void, _al_remove_display_validated_callback, (ALLEGRO_DISPLAY *display,
-   void (*display_validated)(ALLEGRO_DISPLAY*)));
 
 /* Defined in tls.c */
 bool _al_set_current_display_only(ALLEGRO_DISPLAY *display);
 void _al_set_new_display_settings(ALLEGRO_EXTRA_DISPLAY_SETTINGS *settings);
 ALLEGRO_EXTRA_DISPLAY_SETTINGS *_al_get_new_display_settings(void);
 
-
 #ifdef __cplusplus
 }
 #endif
