@@ -1,6 +1,7 @@
 #ifndef __al_included_allegro5_aintern_opengl_h
 #define __al_included_allegro5_aintern_opengl_h
 
+#include "allegro5/opengl/gl_ext.h"
 #include "allegro5/internal/aintern_bitmap.h"
 #include "allegro5/internal/aintern_display.h"
 
@@ -124,6 +125,7 @@ void _al_ogl_reset_fbo_info(ALLEGRO_FBO_INFO *info);
 bool _al_ogl_create_persistent_fbo(ALLEGRO_BITMAP *bitmap);
 ALLEGRO_FBO_INFO *_al_ogl_persist_fbo(ALLEGRO_DISPLAY *display,
                                       ALLEGRO_FBO_INFO *transient_fbo_info);
+void _al_ogl_setup_gl(ALLEGRO_DISPLAY *d);
 void _al_ogl_set_target_bitmap(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap);
 void _al_ogl_setup_bitmap_clipping(const ALLEGRO_BITMAP *bitmap);
 ALLEGRO_BITMAP *_al_ogl_get_backbuffer(ALLEGRO_DISPLAY *d);
@@ -136,4 +138,6 @@ struct ALLEGRO_DISPLAY_INTERFACE;
 /* draw */
 void _al_ogl_add_drawing_functions(struct ALLEGRO_DISPLAY_INTERFACE *vt);
 
+AL_FUNC(bool, _al_opengl_set_blender, (ALLEGRO_DISPLAY *disp));
+
 #endif
