@@ -6,11 +6,7 @@
 #endif
 
 
-#if defined ALLEGRO_MACOSX || defined ALLEGRO_GP2XWIZ || defined ALLEGRO_IPHONE
-// Do some one-time initialisation for the thread support
-void _al_pthreads_tls_init(void);
-#endif
-
+void _al_tls_init_once(void);
 
 int *_al_tls_get_dtor_owner_count(void);
 
