@@ -16,13 +16,27 @@
  *      See readme.txt for copyright information.
  */
 
+#include "allegro5/platform/alplatf.h"
 
-#define AL_INLINE(type, name, args, code)    type name args code
+// apple's cross-compiler already adds the symbols for the "extern __inline__"
+// declared variants, so the ones here are duplicates and the linker dies
+#ifndef ALLEGRO_IPHONE
 
-#include "allegro.h"
-#include "allegro/internal/aintern.h"
+#define AL_INLINE(type, name, args, code)    \
+   extern type name args; \
+   type name args code
+
+#include "allegro5/allegro.h"
+#include "allegro5/internal/aintern.h"
 
 #ifdef ALLEGRO_INTERNAL_HEADER
    #include ALLEGRO_INTERNAL_HEADER
 #endif
 
+/* not used now */
+/* #include "allegro5/internal/aintern_atomicops.h" */
+
+#include "allegro5/internal/aintern_float.h"
+#include "allegro5/internal/aintern_vector.h"
+
+#endif
