@@ -1,3 +1,5 @@
+#error This file is no longer used.
+
 /*         ______   ___    ___
  *        /\  _  \ /\_ \  /\_ \
  *        \ \ \L\ \\//\ \ \//\ \      __     __   _ __   ___
@@ -19,10 +21,10 @@
  */
 
 
-#include "allegro.h"
-#include "allegro/internal/aintern.h"
-#include "allegro/platform/aintunix.h"
-#include "linalleg.h"
+#include "allegro5/allegro.h"
+#include "allegro5/internal/aintern.h"
+#include "allegro5/platform/aintunix.h"
+#include "allegro5/linalleg.h"
 
 
 static int mouse_mx = 0;            /* internal position, in mickeys */
@@ -190,7 +192,8 @@ static int update_mouse (void)
    fd_set set;
    struct timeval tv = { 0, 0 };
 
-   if (resume_count <= 0) return 0;
+   if (resume_count <= 0)
+      return 0;
 
    FD_ZERO(&set);
    FD_SET(std_mouse.fd, &set);
