@@ -161,10 +161,14 @@ static void setup_fbo(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
       bitmap = bitmap->parent;
    ogl_bitmap = (void *)bitmap;
 
-#if !defined ALLEGRO_GP2XWIZ
-   if (display->ogl_extras->opengl_target == ogl_bitmap)
+   /* We can't return here. Target's FBO can be taken away by locking
+    * a lot of bitmaps consecutively.
+    * Also affects ex_multiwin; resizing one window affects the other.
+    */
+   if (false && display->ogl_extras->opengl_target == ogl_bitmap)
       return;
 
+#if !defined ALLEGRO_GP2XWIZ
    if (!ogl_bitmap->is_backbuffer) {
       ALLEGRO_FBO_INFO *info = NULL;
 
@@ -207,6 +211,7 @@ static void setup_fbo(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
          ASSERT(display->ogl_extras->extension_list->ALLEGRO_GL_EXT_framebuffer_object ||
             display->ogl_extras->extension_list->ALLEGRO_GL_OES_framebuffer_object);
 #endif
+
          if (info->fbo_state == FBO_INFO_UNUSED)
             info->fbo_state = FBO_INFO_TRANSIENT;
          info->owner = ogl_bitmap;
@@ -225,7 +230,7 @@ static void setup_fbo(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
              * message and switch to (extremely slow) software mode.
              */
             ALLEGRO_ERROR("Could not use FBO for bitmap with format %s.\n",
-               _al_format_name(bitmap->format));
+               _al_pixel_format_name(bitmap->format));
             ALLEGRO_ERROR("*** SWITCHING TO SOFTWARE MODE ***\n");
             glBindFramebufferEXT(GL_FRAMEBUFFER_EXT, 0);
             glDeleteFramebuffersEXT(1, &info->fbo);
@@ -268,9 +273,6 @@ static void setup_fbo(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
       #endif
    }
 #else
-   if (display->ogl_extras->opengl_target == ogl_bitmap)
-      return;
-
    ALLEGRO_DISPLAY_GP2XWIZ_OGL *wiz_disp = (ALLEGRO_DISPLAY_GP2XWIZ_OGL *)display;
    display->ogl_extras->opengl_target = ogl_bitmap;
 
@@ -293,6 +295,27 @@ static void setup_fbo(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
 }
 
 
+/* Helper to set up GL state as we want it. */
+void _al_ogl_setup_gl(ALLEGRO_DISPLAY *d)
+{
+   ALLEGRO_OGL_EXTRAS *ogl = d->ogl_extras;
+
+   glViewport(0, 0, d->w, d->h);
+
+   glMatrixMode(GL_PROJECTION);
+   glLoadIdentity();
+   glOrtho(0, d->w, d->h, 0, -1, 1);
+
+   glMatrixMode(GL_MODELVIEW);
+   glLoadIdentity();
+
+   if (ogl->backbuffer)
+      _al_ogl_resize_backbuffer(ogl->backbuffer, d->w, d->h);
+   else
+      ogl->backbuffer = _al_ogl_create_backbuffer(d);
+}
+
+
 void _al_ogl_set_target_bitmap(ALLEGRO_DISPLAY *display, ALLEGRO_BITMAP *bitmap)
 {
    ALLEGRO_BITMAP_OGL *ogl_bitmap = (void *)bitmap;
@@ -358,13 +381,15 @@ void _al_ogl_setup_bitmap_clipping(const ALLEGRO_BITMAP *bitmap)
          /* Can only disable scissor if the sub-bitmap covers the
           * complete parent.
           */
-         if (bitmap->xofs == 0 && bitmap->yofs == 0 && bitmap->w ==
-            bitmap->parent->w && bitmap->h == bitmap->parent->h) {
-               use_scissor = false;
-            }
+         if (bitmap->xofs == 0 && bitmap->yofs == 0 &&
+            bitmap->w == bitmap->parent->w && bitmap->h == bitmap->parent->h)
+         {
+            use_scissor = false;
+         }
       }
-      else
+      else {
          use_scissor = false;
+      }
    }
    if (!use_scissor) {
       glDisable(GL_SCISSOR_TEST);
@@ -453,7 +478,7 @@ ALLEGRO_BITMAP_OGL* _al_ogl_create_backbuffer(ALLEGRO_DISPLAY *disp)
    }
 #endif
    ALLEGRO_TRACE_CHANNEL_LEVEL("display", 1)("Deduced format %s for backbuffer.\n",
-      _al_format_name(format));
+      _al_pixel_format_name(format));
 
    /* Now that the display backbuffer has a format, update extra_settings so
     * the user can query it back.
@@ -463,7 +488,8 @@ ALLEGRO_BITMAP_OGL* _al_ogl_create_backbuffer(ALLEGRO_DISPLAY *disp)
 
    ALLEGRO_DEBUG("Creating backbuffer bitmap\n");
    al_set_new_bitmap_format(format);
-   al_set_new_bitmap_flags(ALLEGRO_VIDEO_BITMAP);
+   /* Using ALLEGRO_NO_PRESERVE_TEXTURE prevents extra memory being allocated */
+   al_set_new_bitmap_flags(ALLEGRO_VIDEO_BITMAP | ALLEGRO_NO_PRESERVE_TEXTURE);
    backbuffer = _al_ogl_create_bitmap(disp, disp->w, disp->h);
    al_restore_state(&backup);
 
@@ -474,7 +500,7 @@ ALLEGRO_BITMAP_OGL* _al_ogl_create_backbuffer(ALLEGRO_DISPLAY *disp)
    
    ALLEGRO_TRACE_CHANNEL_LEVEL("display", 1)(
       "Created backbuffer bitmap (actual format: %s)\n",
-      _al_format_name(backbuffer->format));
+      _al_pixel_format_name(backbuffer->format));
 
    ogl_backbuffer = (ALLEGRO_BITMAP_OGL*)backbuffer;
    ogl_backbuffer->is_backbuffer = 1;
