@@ -8,24 +8,19 @@
  *                                           /\____/
  *                                           \_/__/
  *
- *      Pixel manipulation.
+ *      Pixel formats.
  *
  *      By Trent Gamblin.
  *
+ *      See LICENSE.txt for copyright information.
  */
 
-/* Title: Pixel manipulation
- */
-
-#include <string.h> /* for memset */
 #include "allegro5/allegro.h"
-#include "allegro5/bitmap.h"
-#include "allegro5/internal/aintern.h"
-#include "allegro5/internal/aintern_bitmap.h"
 #include "allegro5/internal/aintern_pixels.h"
 
 ALLEGRO_DEBUG_CHANNEL("pixels")
 
+
 /* lookup table for scaling 8 bit integers up to floats [0.0, 1.0] */
 float _al_u8_to_float[256];
 int _al_rgb_scale_1[2];
@@ -93,21 +88,6 @@ static int pixel_bits[] = {
    16 /* ALLEGRO_PIXEL_FORMAT_RGBA_4444 */
 };
 
-
-/* Function: al_get_pixel_size
- */
-int al_get_pixel_size(int format)
-{
-   return pixel_sizes[format];
-}
-
-/* Function: al_get_pixel_format_bits
- */
-int al_get_pixel_format_bits(int format)
-{
-   return pixel_bits[format];
-}
-
 static bool format_alpha_table[ALLEGRO_NUM_PIXEL_FORMATS] = {
    false, /* neutral (ALLEGRO_PIXEL_FORMAT_ANY) */
    false,
@@ -169,11 +149,6 @@ static char const *pixel_format_names[ALLEGRO_NUM_PIXEL_FORMATS + 1] = {
    "INVALID"
 };
 
-bool _al_format_has_alpha(int format)
-{
-   return format_alpha_table[format];
-}
-
 static bool format_is_real[ALLEGRO_NUM_PIXEL_FORMATS] =
 {
    false, /* ALLEGRO_PIXEL_FORMAT_ANY */
@@ -206,6 +181,48 @@ static bool format_is_real[ALLEGRO_NUM_PIXEL_FORMATS] =
 };
 
 
+void _al_init_pixels(void)
+{
+   int i;
+   for (i = 0; i < 256; i++)
+      _al_u8_to_float[i] = i / 255.0;
+
+   for (i = 0; i < 2; i++)
+      _al_rgb_scale_1[i] = i * 255 / 1;
+
+   for (i = 0; i < 16; i++)
+      _al_rgb_scale_4[i] = i * 255 / 15;
+
+   for (i = 0; i < 32; i++)
+      _al_rgb_scale_5[i] = i * 255 / 31;
+
+   for (i = 0; i < 64; i++)
+      _al_rgb_scale_6[i] = i * 255 / 63;
+}
+
+
+/* Function: al_get_pixel_size
+ */
+int al_get_pixel_size(int format)
+{
+   return pixel_sizes[format];
+}
+
+
+/* Function: al_get_pixel_format_bits
+ */
+int al_get_pixel_format_bits(int format)
+{
+   return pixel_bits[format];
+}
+
+
+bool _al_pixel_format_has_alpha(int format)
+{
+   return format_alpha_table[format];
+}
+
+
 bool _al_pixel_format_is_real(int format)
 {
    ASSERT(format >= 0);
@@ -214,6 +231,7 @@ bool _al_pixel_format_is_real(int format)
    return format_is_real[format];
 }
 
+
 /* We use al_get_display_format() as a hint for the preferred RGB ordering when
  * nothing else is specified.
  */
@@ -234,7 +252,9 @@ static bool try_display_format(ALLEGRO_DISPLAY *display, int *format)
    if (bytes && bytes != al_get_pixel_size(best_format))
       return false;
 
-   if (_al_format_has_alpha(*format) && !_al_format_has_alpha(best_format)) {
+   if (_al_pixel_format_has_alpha(*format) &&
+      !_al_pixel_format_has_alpha(best_format))
+   {
       switch (best_format) {
          case ALLEGRO_PIXEL_FORMAT_RGBX_8888:
             *format = ALLEGRO_PIXEL_FORMAT_RGBA_8888;
@@ -253,6 +273,7 @@ static bool try_display_format(ALLEGRO_DISPLAY *display, int *format)
    return true;
 }
 
+
 int _al_get_real_pixel_format(ALLEGRO_DISPLAY *display, int format)
 {
    /* Pick an appropriate format if the user is vague */
@@ -291,6 +312,13 @@ int _al_get_real_pixel_format(ALLEGRO_DISPLAY *display, int format)
 }
 
 
+char const *_al_pixel_format_name(ALLEGRO_PIXEL_FORMAT format)
+{
+   if (format >= ALLEGRO_NUM_PIXEL_FORMATS) format = ALLEGRO_NUM_PIXEL_FORMATS;
+   return pixel_format_names[format];
+}
+
+
 /* Color mapping functions */
 
 /* Function: al_map_rgba
@@ -334,125 +362,6 @@ ALLEGRO_COLOR al_map_rgb_f(float r, float g, float b)
 }
 
 
-/* Function: al_get_pixel
- */
-ALLEGRO_COLOR al_get_pixel(ALLEGRO_BITMAP *bitmap, int x, int y)
-{
-   ALLEGRO_LOCKED_REGION *lr;
-   char *data;
-   ALLEGRO_COLOR color;
-
-   if (bitmap->parent) {
-      x += bitmap->xofs;
-      y += bitmap->yofs;
-      bitmap = bitmap->parent;
-   }
-
-   if (bitmap->locked) {
-      x -= bitmap->lock_x;
-      y -= bitmap->lock_y;
-      if (x < 0 || y < 0 || x >= bitmap->lock_w || y >= bitmap->lock_h) {
-         ALLEGRO_ERROR("Out of bounds.");
-         memset(&color, 0, sizeof(ALLEGRO_COLOR));
-         return color;
-      }
-
-      data = bitmap->locked_region.data;
-      data += y * bitmap->locked_region.pitch;
-      data += x * al_get_pixel_size(bitmap->locked_region.format);
-
-      _AL_INLINE_GET_PIXEL(bitmap->locked_region.format, data, color, false);
-   }
-   else {
-      /* FIXME: must use clip not full bitmap */
-      if (x < 0 || y < 0 || x >= bitmap->w || y >= bitmap->h) {
-         memset(&color, 0, sizeof(ALLEGRO_COLOR));
-         return color;
-      }
-
-      if (!(lr = al_lock_bitmap_region(bitmap, x, y, 1, 1, bitmap->format,
-            ALLEGRO_LOCK_READONLY)))
-      {
-         memset(&color, 0, sizeof(ALLEGRO_COLOR));
-         return color;
-      }
-
-      /* FIXME: check for valid pixel format */
-
-      data = lr->data;
-      _AL_INLINE_GET_PIXEL(bitmap->format, data, color, false);
-
-      al_unlock_bitmap(bitmap);
-   }
-
-   return color;
-}
-
-
-void _al_put_pixel(ALLEGRO_BITMAP *bitmap, int x, int y, ALLEGRO_COLOR color)
-{
-   ALLEGRO_LOCKED_REGION *lr;
-   char *data;
-
-   if (bitmap->parent) {
-       x += bitmap->xofs;
-       y += bitmap->yofs;
-       bitmap = bitmap->parent;
-   }
-
-   if (x < bitmap->cl || y < bitmap->ct ||
-       x >= bitmap->cr_excl || y >= bitmap->cb_excl)
-   {
-      return;
-   }
-
-   if (bitmap->locked) {
-      x -= bitmap->lock_x;
-      y -= bitmap->lock_y;
-      if (x < 0 || y < 0 || x >= bitmap->lock_w || y >= bitmap->lock_h) {
-         return;
-      }
-
-      data = bitmap->locked_region.data;
-      data += y * bitmap->locked_region.pitch;
-      data += x * al_get_pixel_size(bitmap->locked_region.format);
-
-      _AL_INLINE_PUT_PIXEL(bitmap->locked_region.format, data, color, false);
-   }
-   else {
-      lr = al_lock_bitmap_region(bitmap, x, y, 1, 1, bitmap->format,
-         ALLEGRO_LOCK_WRITEONLY);
-      if (!lr)
-         return;
-
-      /* FIXME: check for valid pixel format */
-
-      data = lr->data;
-      _AL_INLINE_PUT_PIXEL(bitmap->format, data, color, false);
-
-      al_unlock_bitmap(bitmap);
-   }
-}
-
-
-/* Function: al_put_pixel
- */
-void al_put_pixel(int x, int y, ALLEGRO_COLOR color)
-{
-   _al_put_pixel(al_get_target_bitmap(), x, y, color);
-}
-
-/* Function: al_put_blended_pixel
- */
-void al_put_blended_pixel(int x, int y, ALLEGRO_COLOR color)
-{
-   ALLEGRO_COLOR result;
-   ALLEGRO_BITMAP* bitmap = al_get_target_bitmap();
-   _al_blend_memory(&color, bitmap, x, y, &result);
-   _al_put_pixel(bitmap, x, y, result);
-}
-
-
 /* unmapping functions */
 
 
@@ -501,29 +410,4 @@ void al_unmap_rgb_f(ALLEGRO_COLOR color, float *r, float *g, float *b)
 }
 
 
-void _al_init_pixels(void)
-{
-   int i;
-   for (i = 0; i < 256; i++)
-      _al_u8_to_float[i] = i / 255.0;
-
-   for (i = 0; i < 2; i++)
-      _al_rgb_scale_1[i] = i * 255 / 1;
-
-   for (i = 0; i < 16; i++)
-      _al_rgb_scale_4[i] = i * 255 / 15;
-
-   for (i = 0; i < 32; i++)
-      _al_rgb_scale_5[i] = i * 255 / 31;
-
-   for (i = 0; i < 64; i++)
-      _al_rgb_scale_6[i] = i * 255 / 63;
-}
-
-char const *_al_format_name(ALLEGRO_PIXEL_FORMAT format)
-{
-   if (format >= ALLEGRO_NUM_PIXEL_FORMATS) format = ALLEGRO_NUM_PIXEL_FORMATS;
-   return pixel_format_names[format];
-}
-
 /* vim: set sts=3 sw=3 et: */
