@@ -22,13 +22,15 @@
 #include "allegro5/internal/aintern.h"
 #include ALLEGRO_INTERNAL_HEADER
 #include "allegro5/internal/aintern_bitmap.h"
+#include "allegro5/internal/aintern_debug.h"
 #include "allegro5/internal/aintern_dtor.h"
-#include "allegro5/internal/aintern_system.h"
-#include "allegro5/internal/aintern_vector.h"
+#include "allegro5/internal/aintern_exitfunc.h"
 #include "allegro5/internal/aintern_pixels.h"
+#include "allegro5/internal/aintern_system.h"
 #include "allegro5/internal/aintern_thread.h"
 #include "allegro5/internal/aintern_timer.h"
 #include "allegro5/internal/aintern_tls.h"
+#include "allegro5/internal/aintern_vector.h"
 
 ALLEGRO_DEBUG_CHANNEL("system")
 
@@ -44,26 +46,6 @@ static bool atexit_virgin = true;
 static char _al_app_name[256] = "";
 static char _al_org_name[256] = "";
 
-#if 0
-bool al_register_system_driver(ALLEGRO_SYSTEM_INTERFACE *sys_interface)
-{
-   ALLEGRO_SYSTEM_INTERFACE **add = _al_vector_alloc_back(&_user_system_interfaces);
-   if (!add)
-      return false;
-   *add = sys_interface;
-   return true;
-}
-#endif
-
-
-
-#if 0
-void al_unregister_system_driver(ALLEGRO_SYSTEM_INTERFACE *sys_interface)
-{
-   _al_vector_find_and_delete(&_user_system_interfaces, &sys_interface);
-}
-#endif
-
 
 
 static ALLEGRO_SYSTEM *find_system(_AL_VECTOR *vector)
@@ -116,10 +98,10 @@ static ALLEGRO_PATH *early_get_exename_path(void)
    return _al_win_get_path(ALLEGRO_EXENAME_PATH);
 #elif defined(ALLEGRO_MACOSX)
    return _al_osx_get_path(ALLEGRO_EXENAME_PATH);
-#elif defined(ALLEGRO_UNIX)
-   return _al_unix_get_path(ALLEGRO_EXENAME_PATH);
 #elif defined(ALLEGRO_IPHONE)
    return _al_iphone_get_path(ALLEGRO_EXENAME_PATH);
+#elif defined(ALLEGRO_UNIX)
+   return _al_unix_get_path(ALLEGRO_EXENAME_PATH);
 #else
    #error early_get_exename_path not implemented
 #endif
@@ -230,10 +212,8 @@ bool al_install_system(int version, int (*atexit_ptr)(void (*)(void)))
    if (!compatible_versions(version, library_version))
       return false;
 
-#ifdef ALLEGRO_CFG_PTHREADS_TLS
-   _al_pthreads_tls_init();
-#endif
-   
+   _al_tls_init_once();
+
    _al_vector_init(&_al_system_interfaces, sizeof(ALLEGRO_SYSTEM_INTERFACE *));
 
    /* We want active_sysdrv->config to be available as soon as
@@ -297,6 +277,8 @@ bool al_install_system(int version, int (*atexit_ptr)(void (*)(void)))
 
    active_sysdrv->installed = true;
 
+   _al_srand(time(NULL));
+
    return true;
 }
 
@@ -310,7 +292,7 @@ void al_uninstall_system(void)
    _al_run_exit_funcs();
    _al_shutdown_destructors(_al_dtor_list);
    _al_dtor_list = NULL;
-
+   _al_shutdown_logging();
 
    /* shutdown_system_driver is registered as an exit func so we don't need
     * to do any more here.
