@@ -16,10 +16,18 @@
  */
 
 
-#include "allegro.h"
+#include "allegro5/allegro.h"
+#include "allegro5/platform/aintunix.h"
+#include "allegro5/internal/aintern.h"
+#include "allegro5/internal/aintern_joystick.h"
 
 
 
-BEGIN_JOYSTICK_DRIVER_LIST
-   /* todo */
-END_JOYSTICK_DRIVER_LIST
+_AL_BEGIN_JOYSTICK_DRIVER_LIST
+#ifdef ALLEGRO_GP2XWIZ
+   _AL_JOYSTICK_DRIVER_GP2XWIZ
+#endif
+#if defined ALLEGRO_HAVE_LINUX_JOYSTICK_H && defined ALLEGRO_WITH_XWINDOWS
+   { _ALLEGRO_JOYDRV_LINUX,   &_al_joydrv_linux,   true  },
+#endif
+_AL_END_JOYSTICK_DRIVER_LIST
