@@ -23,6 +23,8 @@
 #include "allegro5/internal/aintern.h"
 #include "allegro5/internal/aintern_bitmap.h"
 #include "allegro5/internal/aintern_display.h"
+#include "allegro5/internal/aintern_memblit.h"
+#include "allegro5/internal/aintern_pixels.h"
 #include "allegro5/internal/aintern_system.h"
 #include "allegro5/platform/aintwin.h"
 
@@ -304,7 +306,7 @@ static bool d3d_create_textures(ALLEGRO_DISPLAY_D3D *disp, int w, int h,
       if (video_texture) {
          err = disp->device->CreateTexture(w, h, levels,
             D3DUSAGE_RENDERTARGET | autogenmipmap,
-            (D3DFORMAT)_al_format_to_d3d(format), D3DPOOL_DEFAULT,
+            (D3DFORMAT)_al_pixel_format_to_d3d(format), D3DPOOL_DEFAULT,
             video_texture, NULL);
          if (err != D3D_OK && err != D3DOK_NOAUTOGEN) {
             ALLEGRO_ERROR("d3d_create_textures: Unable to create video texture.\n");
@@ -314,7 +316,7 @@ static bool d3d_create_textures(ALLEGRO_DISPLAY_D3D *disp, int w, int h,
 
       if (system_texture) {
          err = disp->device->CreateTexture(w, h, 1,
-            0, (D3DFORMAT)_al_format_to_d3d(format), D3DPOOL_SYSTEMMEM,
+            0, (D3DFORMAT)_al_pixel_format_to_d3d(format), D3DPOOL_SYSTEMMEM,
             system_texture, NULL);
          if (err != D3D_OK) {
             ALLEGRO_ERROR("d3d_create_textures: Unable to create system texture.\n");
@@ -331,7 +333,7 @@ static bool d3d_create_textures(ALLEGRO_DISPLAY_D3D *disp, int w, int h,
    else {
       if (video_texture) {
          err = disp->device->CreateTexture(w, h, 1,
-            0, (D3DFORMAT)_al_format_to_d3d(format), D3DPOOL_MANAGED,
+            0, (D3DFORMAT)_al_pixel_format_to_d3d(format), D3DPOOL_MANAGED,
             video_texture, NULL);
          if (err != D3D_OK) {
             ALLEGRO_ERROR("d3d_create_textures: Unable to create video texture (no render-to-texture).\n");
@@ -408,59 +410,75 @@ static ALLEGRO_BITMAP
 }
 
 /* Copies video texture to system texture and bitmap->memory */
-static void _al_d3d_sync_bitmap(ALLEGRO_BITMAP *dest)
+static bool _al_d3d_sync_bitmap(ALLEGRO_BITMAP *dest)
 {
    ALLEGRO_BITMAP_D3D *d3d_dest;
    LPDIRECT3DSURFACE9 system_texture_surface;
    LPDIRECT3DSURFACE9 video_texture_surface;
+   bool ok;
    UINT i;
 
-   if (!_al_d3d_render_to_texture_supported())
-      return;
+   if (!_al_d3d_render_to_texture_supported()) {
+      ALLEGRO_ERROR("Render-to-texture not supported.\n");
+      return false;
+   }
 
    if (dest->locked) {
-      return;
+      ALLEGRO_ERROR("Already locked.\n");
+      return false;
    }
 
    d3d_dest = (ALLEGRO_BITMAP_D3D *)dest;
 
    if (d3d_dest->system_texture == NULL || d3d_dest->video_texture == NULL) {
-      return;
+      ALLEGRO_ERROR("A texture is null.\n");
+      return false;
    }
 
    if (dest->parent) {
       dest = dest->parent;
    }
 
+   ok = true;
+   system_texture_surface = NULL;
+   video_texture_surface = NULL;
+
    if (d3d_dest->system_texture->GetSurfaceLevel(
          0, &system_texture_surface) != D3D_OK) {
       ALLEGRO_ERROR("_al_d3d_sync_bitmap: GetSurfaceLevel failed while updating video texture.\n");
-      return;
+      ok = false;
    }
 
-   if (d3d_dest->video_texture->GetSurfaceLevel(
+   if (ok && d3d_dest->video_texture->GetSurfaceLevel(
          0, &video_texture_surface) != D3D_OK) {
       ALLEGRO_ERROR("_al_d3d_sync_bitmap: GetSurfaceLevel failed while updating video texture.\n");
-      return;
+      ok = false;
    }
 
-   if (d3d_dest->display->device->GetRenderTargetData(
+   if (ok && d3d_dest->display->device->GetRenderTargetData(
          video_texture_surface,
          system_texture_surface) != D3D_OK) {
       ALLEGRO_ERROR("_al_d3d_sync_bitmap: GetRenderTargetData failed.\n");
-      return;
+      ok = false;
    }
 
-   if ((i = system_texture_surface->Release()) != 0) {
-      ALLEGRO_DEBUG("_al_d3d_sync_bitmap (system) ref count == %d\n", i);
+   if (system_texture_surface) {
+       if ((i = system_texture_surface->Release()) != 0) {
+	  ALLEGRO_DEBUG("_al_d3d_sync_bitmap (system) ref count == %d\n", i);
+       }
+   }
+   if (video_texture_surface) {
+       if ((i = video_texture_surface->Release()) != 0) {
+	  // This can be non-zero
+	  ALLEGRO_DEBUG("_al_d3d_sync_bitmap (video) ref count == %d\n", i);
+       }
    }
 
-   if ((i = video_texture_surface->Release()) != 0) {
-      // This can be non-zero
-      ALLEGRO_DEBUG("_al_d3d_sync_bitmap (video) ref count == %d\n", i);
+   if (ok) {
+      d3d_sync_bitmap_memory(dest);
    }
 
-   d3d_sync_bitmap_memory(dest);
+   return ok;
 }
 
 /*
@@ -776,7 +794,9 @@ static ALLEGRO_LOCKED_REGION *d3d_lock_region(ALLEGRO_BITMAP *bitmap,
 	  * Sync bitmap->memory with texture
           */
 	 bitmap->locked = false;
-         _al_d3d_sync_bitmap(bitmap);
+         if (!_al_d3d_sync_bitmap(bitmap)) {
+            return NULL;
+         }
 	 bitmap->locked = true;
          texture = d3d_bmp->system_texture;
       }
