@@ -1,5 +1,5 @@
 /*         ______   ___    ___ 
- *        /\  _  \ /\_ \  /\_ \ 
+ *        /\  _  \ /\_ \  /\_ \
  *        \ \ \L\ \\//\ \ \//\ \      __     __   _ __   ___ 
  *         \ \  __ \ \ \ \  \ \ \   /'__`\ /'_ `\/\`'__\/ __`\
  *          \ \ \/\ \ \_\ \_ \_\ \_/\  __//\ \L\ \ \ \//\ \L\ \
@@ -1102,8 +1102,27 @@ static void destroy_display_internals(ALLEGRO_DISPLAY_WGL *wgl_disp)
    _al_ogl_unmanage_extensions(disp);
 
    PostMessage(win_disp->window, _al_win_msg_suicide, (WPARAM)win_disp, 0);
+
    while (!win_disp->thread_ended)
       al_rest(0.001);
+
+   if (wgl_disp->glrc) {
+      wglDeleteContext(wgl_disp->glrc);
+      wgl_disp->glrc = NULL;
+   }
+   if (wgl_disp->dc) {
+      ReleaseDC(win_disp->window, wgl_disp->dc);
+      wgl_disp->dc = NULL;
+   }
+
+   if (disp->flags & ALLEGRO_FULLSCREEN && !_wgl_do_not_change_display_mode) {
+      ChangeDisplaySettings(NULL, 0);
+   }
+
+   if (win_disp->window) {
+      DestroyWindow(win_disp->window);
+      win_disp->window = NULL;
+   }
 }
 
 
@@ -1308,24 +1327,6 @@ static void display_thread_proc(void *arg)
          break;                 /* WM_QUIT received or error (GetMessage returned -1)  */
    }
 
-   if (wgl_disp->glrc) {
-      wglDeleteContext(wgl_disp->glrc);
-      wgl_disp->glrc = NULL;
-   }
-   if (wgl_disp->dc) {
-      ReleaseDC(win_disp->window, wgl_disp->dc);
-      wgl_disp->dc = NULL;
-   }
-
-   if (disp->flags & ALLEGRO_FULLSCREEN && !_wgl_do_not_change_display_mode) {
-      ChangeDisplaySettings(NULL, 0);
-   }
-
-   if (win_disp->window) {
-      DestroyWindow(win_disp->window);
-      win_disp->window = NULL;
-   }
-
    ALLEGRO_INFO("wgl display thread exits\n");
    win_disp->thread_ended = true;
 }
@@ -1334,9 +1335,8 @@ static void display_thread_proc(void *arg)
 static void wgl_flip_display(ALLEGRO_DISPLAY *d)
 {
    ALLEGRO_DISPLAY_WGL* disp = (ALLEGRO_DISPLAY_WGL*)d;
-   if (d->extra_settings.settings[ALLEGRO_SINGLE_BUFFER])
-      glFlush();
-   else
+   glFlush();
+   if (!d->extra_settings.settings[ALLEGRO_SINGLE_BUFFER])
       SwapBuffers(disp->dc);
 }
 
@@ -1478,6 +1478,7 @@ static bool wgl_acknowledge_resize(ALLEGRO_DISPLAY *d)
    ALLEGRO_DISPLAY_WIN *win_disp = (ALLEGRO_DISPLAY_WIN *)d;
    ALLEGRO_DISPLAY *ogl_disp = (ALLEGRO_DISPLAY *)d;
    int w, h;
+   ALLEGRO_STATE state;
 
    wi.cbSize = sizeof(WINDOWINFO);
    GetWindowInfo(win_disp->window, &wi);
@@ -1490,6 +1491,11 @@ static bool wgl_acknowledge_resize(ALLEGRO_DISPLAY *d)
    setup_gl(d);
    _al_ogl_resize_backbuffer(ogl_disp->ogl_extras->backbuffer, w, h);
 
+   al_store_state(&state, ALLEGRO_STATE_DISPLAY | ALLEGRO_STATE_TARGET_BITMAP);
+   al_set_target_backbuffer(d);
+   al_set_clipping_rectangle(0, 0, w, h);
+   al_restore_state(&state);
+
    return true;
 }
 
@@ -1562,7 +1568,7 @@ ALLEGRO_DISPLAY_INTERFACE *_al_display_wgl_driver(void)
    vt.show_mouse_cursor = _al_win_show_mouse_cursor;
    vt.hide_mouse_cursor = _al_win_hide_mouse_cursor;
 
-   vt.set_icon = _al_win_set_display_icon;
+   vt.set_icons = _al_win_set_display_icons;
    vt.set_window_position = wgl_set_window_position;
    vt.get_window_position = wgl_get_window_position;
    vt.set_display_flag = _al_win_set_display_flag;
@@ -1619,6 +1625,26 @@ ALLEGRO_DISPLAY_MODE *_al_wgl_get_display_mode(int index, int format,
    mode->width = dm.dmPelsWidth;
    mode->height = dm.dmPelsHeight;
    mode->refresh_rate = dm.dmDisplayFrequency;
+   mode->format = format;
+   switch (dm.dmBitsPerPel) {
+      case 32:
+         if (format == ALLEGRO_PIXEL_FORMAT_ANY)
+            mode->format = ALLEGRO_PIXEL_FORMAT_ANY_32_WITH_ALPHA;
+         else if (format == ALLEGRO_PIXEL_FORMAT_ANY_NO_ALPHA)
+            mode->format = ALLEGRO_PIXEL_FORMAT_ANY_32_NO_ALPHA;
+         break;
+      case 24:
+         mode->format = ALLEGRO_PIXEL_FORMAT_ANY_24_NO_ALPHA;
+         break;
+      case 16:
+         if (format == ALLEGRO_PIXEL_FORMAT_ANY)
+            mode->format = ALLEGRO_PIXEL_FORMAT_ANY_16_WITH_ALPHA;
+         else if(format == ALLEGRO_PIXEL_FORMAT_ANY_NO_ALPHA)
+            mode->format = ALLEGRO_PIXEL_FORMAT_ANY_16_NO_ALPHA;
+         break;
+      default:
+         break;
+   }
 
    return mode;
 }
