@@ -17,7 +17,9 @@
  */
 
 
-#include "allegro.h"
+#include "allegro5/allegro.h"
+#include "allegro5/internal/aintern.h"
+#include "allegro5/internal/aintern_joystick.h"
 
 #ifndef ALLEGRO_WINDOWS
 #error something is wrong with the makefile
@@ -25,7 +27,6 @@
 
 
 
-BEGIN_JOYSTICK_DRIVER_LIST
-JOYSTICK_DRIVER_DIRECTX
-JOYSTICK_DRIVER_WIN32
-END_JOYSTICK_DRIVER_LIST
+_AL_BEGIN_JOYSTICK_DRIVER_LIST
+_AL_JOYSTICK_DRIVER_DIRECTX
+_AL_END_JOYSTICK_DRIVER_LIST
